# onnx.backend

## Backend

```{eval-rst}
.. autoclass:: onnx.backend.base.Backend
    :members:
```

## BackendRep

```{eval-rst}
.. autoclass:: onnx.backend.base.BackendRep
    :members:
```

## Device

```{eval-rst}
.. autoclass:: onnx.backend.base.Device
    :members:
```

## DeviceType

```{eval-rst}
.. autoclass:: onnx.backend.base.DeviceType
    :members:
```

## load_model_tests

```{eval-rst}
.. autofunction:: onnx.backend.test.loader.load_model_tests
```
